homescreenpluginsrv/hspsmanager/src/hspsmaintenancehandler.cpp
branchRCL_3
changeset 25 9e077f9a342c
parent 22 1b207dd38b72
child 27 2c7f27287390
--- a/homescreenpluginsrv/hspsmanager/src/hspsmaintenancehandler.cpp	Wed Jun 09 10:01:25 2010 +0300
+++ b/homescreenpluginsrv/hspsmanager/src/hspsmaintenancehandler.cpp	Mon Jun 21 16:00:38 2010 +0300
@@ -4737,14 +4737,28 @@
 //
 void ChspsMaintenanceHandler::HandleReinstallationL(
         const TBool aInstallUdaEmmc ) 
-    {       
+    {
     // Install plug-in configurations from the "install" directories
     iThemeServer.InstallWidgetsL( aInstallUdaEmmc );
     if( aInstallUdaEmmc )
         {
         // Install plug-in configurations from the "import" directories in C and E
         iThemeServer.InstallUDAWidgetsL( KImportDirectoryC );
-        iThemeServer.InstallUDAWidgetsL( KImportDirectoryE );
+
+        TInt drive = hspsServerUtil::GetEmmcDrivePath( 
+                iServerSession->FileSystem() );
+        if ( drive != KErrNotFound )
+            {
+            TDriveUnit unit(drive);
+            HBufC* importDirectoryE = HBufC::NewLC( 
+                    KImportDirectory().Length() + unit.Name().Length() ); 
+            importDirectoryE->Des().Append( unit.Name() );
+            importDirectoryE->Des().Append( KImportDirectory );
+            
+            iThemeServer.InstallUDAWidgetsL( *importDirectoryE );
+            CleanupStack::PopAndDestroy( importDirectoryE );
+            }
         }
     
     // Force updating of the header cache
@@ -4737,14 +4737,28 @@
     if( aInstallUdaEmmc )
         {
-        // Install plug-in configurations from the "import" directories in C and E
+        // Install plug-in configurations from the "import" directories in C 
+        // and emmc(if exists)
         iThemeServer.InstallUDAWidgetsL( KImportDirectoryC );